@@ -12,6 +12,7 @@
 
 // #include the widget headers so that we can call the get_type() static methods:
 
+#include "action.h"
 #include "actiongroup.h"
 #include "appinfo.h"
 #include "application.h"
@@ -80,6 +81,8 @@
 #include "resolver.h"
 #include "seekable.h"
 #include "settings.h"
+#include "simpleaction.h"
+#include "simpleactiongroup.h"
 #include "socket.h"
 #include "socketaddress.h"
 #include "socketaddressenumerator.h"
@@ -165,6 +168,8 @@ GType g_proxy_address_get_type(void);
 GType g_resolver_get_type(void);
 GType g_dbus_server_get_type(void);
 GType g_settings_get_type(void);
+GType g_simple_action_get_type(void);
+GType g_simple_action_group_get_type(void);
 GType g_socket_get_type(void);
 GType g_socket_address_get_type(void);
 GType g_socket_address_enumerator_get_type(void);
@@ -252,6 +257,8 @@ namespace Gio {  class ProxyAddress_Class { public: static Glib::ObjectBase* wra
 namespace Gio {  class Resolver_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio { namespace DBus {  class Server_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
 namespace Gio {  class Settings_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class SimpleAction_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class SimpleActionGroup_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class Socket_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class SocketAddress_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class SocketAddressEnumerator_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -339,6 +346,8 @@ void wrap_init()
   Glib::wrap_register(g_resolver_get_type(), &Gio::Resolver_Class::wrap_new);
   Glib::wrap_register(g_dbus_server_get_type(), &Gio::DBus::Server_Class::wrap_new);
   Glib::wrap_register(g_settings_get_type(), &Gio::Settings_Class::wrap_new);
+  Glib::wrap_register(g_simple_action_get_type(), &Gio::SimpleAction_Class::wrap_new);
+  Glib::wrap_register(g_simple_action_group_get_type(), &Gio::SimpleActionGroup_Class::wrap_new);
   Glib::wrap_register(g_socket_get_type(), &Gio::Socket_Class::wrap_new);
   Glib::wrap_register(g_socket_address_get_type(), &Gio::SocketAddress_Class::wrap_new);
   Glib::wrap_register(g_socket_address_enumerator_get_type(), &Gio::SocketAddressEnumerator_Class::wrap_new);
@@ -417,6 +426,8 @@ void wrap_init()
   Gio::Resolver::get_type();
   Gio::DBus::Server::get_type();
   Gio::Settings::get_type();
+  Gio::SimpleAction::get_type();
+  Gio::SimpleActionGroup::get_type();
   Gio::Socket::get_type();
   Gio::SocketAddress::get_type();
   Gio::SocketAddressEnumerator::get_type();
